@@ -1,5 +1,5 @@
 from urllib.error import HTTPError
-from sendgrid.sendgrid import SendGridAPIClient
+from sendgrid import SendGridAPIClient
 
 
 class SendGridException(Exception):
